#!/bin/ksh
#
#	$Id: build.ksh,v 1.7 2014/11/20 10:24:20 craski-shell_86 Exp $
#
# vim: tabstop=4 shiftwidth=4 softtabstop=4 noexpandtab
#
#-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
#
# Copyright (c) 2013, 2014 Craig R. Skinner <skinner@britvault.co.uk>
#
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#
#-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
#



src='sysexits.h'
dir='src/include'
lib=${src%.*}.sh


function get_src
{
	uname -s | grep -q ^OpenBSD$ &&
	{
		[[ -f /usr/${dir}/${src} ]] &&
		{
			diff -q ${src} /usr/${dir}/${src} > /dev/null 2>&1 ||
			{
				cp -p /usr/${dir}/${src} . && return
			}
		}
	}

	cd $(mktemp -d) || return
	cvs -d anoncvs@anoncvs.ca.openbsd.org:/cvs get ${dir}/${src}
	diff -q ${OLDPWD}/${src} ${dir}/${src} > /dev/null 2>&1 ||
	{
		mv ${dir}/${src} ${OLDPWD}
	}
	cd ${OLDPWD}
	rm -rf ${OLDPWD}
}


[[ -f ${src} ]] &&
{
	read choice?"Update ${src}? [y/N]: "
	[[ ${choice} == @(y|Y) ]] &&
	{
		mv ${src} ${src}~
		get_src
	}
}

[[ -f ${src} ]] ||
{
	read choice?"Get ${src}? [Y/n]: "
	[[ ${choice} == @(n|N) ]] || get_src
	[[ -f ${src} ]] || exit
}


tmp=$(mktemp) || return


# 1) Delete 'C' comment closers, substitute 'C' comment openers with a '#'
# 2) grep out _SYSEXITS_H_ & white space only lines
# 3) Delete '#define ' at the start of lines
# 4) On lines that begin with 'EX_' substitute the first double tabs with singles
# 4) On lines that begin with 'EX_' substitute the first tab with an '='
sed 's~\*/$~~; s~/\*~\#~; s~^ \*~\# ~' ${src} |
	egrep -vi "_${src%.*}_H_|^[[:blank:]]$" |
	sed 's~^\#define ~~' |
	sed '/^EX_/s~		*~	~' |
	sed '/^EX_/s~	~\=~' > ${tmp}


#
# readonly & export EX_*:
#

exits=$(awk -F= '/^EX_/ { print $1 }' ${tmp})

function append_exits
{
	print "\n${1} \\" >> ${tmp}

	for ex_ in ${exits}
	do
		print -n "	${ex_}" >> ${tmp}
		[[ ${ex_} != 'EX__MAX' ]] && print ' \' >> ${tmp}
	done

	print "\n" >> ${tmp}
}

append_exits 'readonly'
append_exits 'export'


diff -q ${tmp} ${lib} > /dev/null 2>&1 ||
{
	cp ${tmp} ${lib} && print "Updated ${lib}"
}

rm ${tmp}

